From 421dd028cea8102550f6b0140a088c588880a28d Mon Sep 17 00:00:00 2001
From: Michael <heluecht@pirati.ca>
Date: Sat, 5 Mar 2022 13:08:09 +0000
Subject: [PATCH] Fix storing mail settings

---
 mod/settings.php       |  2 +-
 src/Protocol/Email.php | 29 +++++++++++++++--------------
 2 files changed, 16 insertions(+), 15 deletions(-)

diff --git a/mod/settings.php b/mod/settings.php
index 2c9dcac126..41a1436e69 100644
--- a/mod/settings.php
+++ b/mod/settings.php
@@ -108,7 +108,7 @@ function settings_post(App $a)
 					'port'         => $mail_port,
 					'ssltype'      => $mail_ssl,
 					'user'         => $mail_user,
-					`action`       => $mail_action,
+					'action'       => $mail_action,
 					'movetofolder' => $mail_movetofolder,
 					'mailbox'      => 'INBOX',
 					'reply_to'     => $mail_replyto,
diff --git a/src/Protocol/Email.php b/src/Protocol/Email.php
index 09792935e0..18af77b3fe 100644
--- a/src/Protocol/Email.php
+++ b/src/Protocol/Email.php
@@ -27,6 +27,7 @@ use Friendica\Content\Text\BBCode;
 use Friendica\Content\Text\HTML;
 use Friendica\Model\Item;
 use Friendica\Util\Strings;
+use \IMAP\Connection;
 
 /**
  * Email class
@@ -37,7 +38,7 @@ class Email
 	 * @param string $mailbox  The mailbox name
 	 * @param string $username The username
 	 * @param string $password The password
-	 * @return resource
+	 * @return Connection
 	 * @throws \Exception
 	 */
 	public static function connect($mailbox, $username, $password)
@@ -50,7 +51,7 @@ class Email
 
 		$errors = imap_errors();
 		if (!empty($errors)) {
-			Logger::notice('IMAP Errors occured', ['errora' => $errors]);
+			Logger::notice('IMAP Errors occured', ['errors' => $errors]);
 		}
 
 		$alerts = imap_alerts();
@@ -62,8 +63,8 @@ class Email
 	}
 
 	/**
 	 * @param resource $mbox       mailbox
 	 * @param string   $email_addr email
 	 * @return array
 	 * @throws \Exception
 	 */
@@ -112,8 +113,8 @@ class Email
 	}
 
 	/**
 	 * @param resource $mbox mailbox
 	 * @param integer  $uid  user id
 	 * @return mixed
 	 */
 	public static function messageMeta($mbox, $uid)
@@ -123,9 +124,9 @@ class Email
 	}
 
 	/**
 	 * @param resource $mbox  mailbox
 	 * @param integer  $uid   user id
 	 * @param string   $reply reply
 	 * @return array
 	 * @throws \Friendica\Network\HTTPException\InternalServerErrorException
 	 */
@@ -210,11 +211,11 @@ class Email
 	/**
 	 * fetch the specified message part number with the specified subtype
 	 *
 	 * @param resource $mbox    mailbox
 	 * @param integer  $uid     user id
 	 * @param object   $p       parts
 	 * @param integer  $partno  part number
 	 * @param string   $subtype sub type
 	 * @return string
 	 */
 	private static function messageGetPart($mbox, $uid, $p, $partno, $subtype)
@@ -62,8 +63,8 @@ class Email
 
 	/**
-	 * @param resource $mbox       mailbox
-	 * @param string   $email_addr email
+	 * @param Connection $mbox       mailbox
+	 * @param string     $email_addr email
 	 * @return array
 	 * @throws \Exception
@@ -112,8 +113,8 @@ class Email
 
 	/**
-	 * @param resource $mbox mailbox
-	 * @param integer  $uid  user id
+	 * @param Connection $mbox mailbox
+	 * @param integer    $uid  user id
 	 * @return mixed
 	 */
@@ -123,9 +124,9 @@ class Email
 
 	/**
-	 * @param resource $mbox  mailbox
-	 * @param integer  $uid   user id
-	 * @param string   $reply reply
+	 * @param Connection $mbox  mailbox
+	 * @param integer    $uid   user id
+	 * @param string     $reply reply
 	 * @return array
 	 * @throws \Friendica\Network\HTTPException\InternalServerErrorException
@@ -210,11 +211,11 @@ class Email
 	 * fetch the specified message part number with the specified subtype
 	 *
-	 * @param resource $mbox    mailbox
-	 * @param integer  $uid     user id
-	 * @param object   $p       parts
-	 * @param integer  $partno  part number
-	 * @param string   $subtype sub type
+	 * @param Connection $mbox    mailbox
+	 * @param integer    $uid     user id
+	 * @param object     $p       parts
+	 * @param integer    $partno  part number
+	 * @param string     $subtype sub type
 	 * @return string
 	 */